<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="商品名称" prop="goodsName" v-if="showHeaderView">
        <el-input
          v-model="queryParams.goodsName"
          placeholder="请输入商品名称"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="是否评价" align="center" prop="comment" v-if="showHeaderView">
        <el-select v-model="queryParams.comment" placeholder="请选择评价状态" clearable size="small">
          <el-option
            v-for="dict in commentStatus"
            :key="dict.dictValue"
            :label="dict.dictLabel"
            :value="dict.dictValue"
          />
        </el-select>
      </el-form-item>
      <el-form-item v-if="showHeaderView">
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8" v-if="showHeaderView">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['mall:mallOrderGoods:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['mall:mallOrderGoods:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['mall:mallOrderGoods:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          :loading="exportLoading"
          @click="handleExport"
          v-hasPermi="['mall:mallOrderGoods:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="mallOrderGoodsList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" v-if="showHeaderView"/>
      <!--<el-table-column label="主键ID" align="center" prop="id" />-->
      <el-table-column label="商品名称" align="center" prop="goodsName" />

      <el-table-column label="商品图片" align="center" prop="goodsImg" >
        <template slot-scope="scope">
          <el-image :src="scope.row.goodsImg" style="width: 80px" :preview-src-list="[scope.row.goodsImg]"/>
        </template>
      </el-table-column>
      <el-table-column label="产品规格名" align="center" prop="productName" />
      <el-table-column label="商品单价" align="center" prop="price" />
      <el-table-column label="购买数量" align="center" prop="total" />
      <el-table-column label="退货数量" align="center" prop="returnTotal" />
<!--      <el-table-column label="退货状态" align="center" prop="returnStatus" >-->
<!--        <template slot-scope="scope">-->
<!--          <div v-if="scope.row.returnStatus == 0">未退货</div>-->
<!--          <div v-if="scope.row.returnStatus == 1">退货中</div>-->
<!--          <div v-if="scope.row.returnStatus == 3">已拒绝</div>-->
<!--          <div v-if="scope.row.returnStatus == 4">取消退货</div>-->
<!--        </template>-->
<!--      </el-table-column>-->
      <!--      <el-table-column label="是否评价" align="center" prop="comment" >-->
      <!--      <template slot-scope="scope">-->
      <!--        <dict-tag :options="commentStatus" :value="scope.row.comment"/>-->
      <!--      </template>-->
      <!--      </el-table-column>-->
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width" v-if="showHeaderView">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['mall:mallOrderGoods:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['mall:mallOrderGoods:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改订单商品对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="商品名称" prop="goodsName">
          <el-input v-model="form.goodsName" placeholder="请输入商品名称" />
        </el-form-item>
        <el-form-item label="商品图片" prop="goodsImg">
          <el-input v-model="form.goodsImg" placeholder="请输入商品图片" />
        </el-form-item>
        <el-form-item label="产品规格名" prop="productName">
          <el-input v-model="form.productName" placeholder="请输入产品规格名" />
        </el-form-item>
        <el-form-item label="商品单价" prop="price">
          <el-input v-model="form.price" placeholder="请输入商品单价" />
        </el-form-item>
        <el-form-item label="购买数量" prop="total">
          <el-input v-model="form.total" placeholder="请输入购买数量" />
        </el-form-item>
        <!--<el-form-item label="是否评价" prop="comment">-->
        <!--<el-input v-model="form.comment" placeholder="请输入是否评价0=未评价,1=已评价" />-->
        <!--</el-form-item>-->
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>

import { listMallOrderGoods, getMallOrderGoods, delMallOrderGoods, addMallOrderGoods, updateMallOrderGoods, exportMallOrderGoods } from "@/api/mall/mallOrderGoods";


export default {
  name: "MallOrderGoods",
  props: {
    // 0-订单商品，1-订单性情
    pageType: {
      type: Number,
      default: 0,
    },
    // 订单id
    orderId: {
      type: Number,
      default: '',
    },
  },
  data() {
    return {
      showHeaderView : true,
      // 遮罩层
      loading: true,
      // 导出遮罩层
      exportLoading: false,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 订单商品表格数据
      mallOrderGoodsList: [],
      commentStatus: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        goodsName: null,
        comment: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        orderId: [
          { required: true, message: "订单主键ID不能为空", trigger: "blur" }
        ],
        goodsId: [
          { required: true, message: "商品主键ID不能为空", trigger: "blur" }
        ],
        productId: [
          { required: true, message: "商品规格ID不能为空", trigger: "blur" }
        ],
      }
    };
  },
  created() {
    this.getInit(this.pageType)
    this.getDicts("mall_order_isComment").then(response => {
      this.commentStatus = response.data;
    });
  },
  methods: {
    /** 查询订单商品列表 */
    getList() {
      this.loading = true;
      listMallOrderGoods(this.queryParams).then(response => {
        this.mallOrderGoodsList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },

    getInit(pageType){
      if (pageType == 0){
        this.getList()
      }else{
        this.showHeaderView = false;
        this.queryParams.orderId=this.orderId;
        this.loading = true;
        listMallOrderGoods(this.queryParams).then(response => {
          this.mallOrderGoodsList = response.rows;
          this.total = response.total;
          this.loading = false;
        });
      }
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        orderId: null,
        goodsId: null,
        productId: null,
        goodsName: null,
        goodsImg: null,
        productName: null,
        price: null,
        total: null,
        comment: null,
        returnStatus: null,
        delFlag: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加订单商品";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getMallOrderGoods(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改订单商品";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateMallOrderGoods(this.form).then(response => {
              this.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addMallOrderGoods(this.form).then(response => {
              this.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$confirm('是否确认删除订单商品编号为"' + ids + '"的数据项?', "警告", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      }).then(function() {
        return delMallOrderGoods(ids);
      }).then(() => {
        this.getList();
        this.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams;
      this.$confirm('是否确认导出所有订单商品数据项?', "警告", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      }).then(() => {
        this.exportLoading = true;
        return exportMallOrderGoods(queryParams);
      }).then(response => {
        this.download(response.msg);
        this.exportLoading = false;
      }).catch(() => {});
    }
  }
};
</script>
